@@ -10,7 +10,7 @@ $editor->run($page, 'sites_content');
 
 if (!$globals->checkRootUrl())
 {
-  $page->assign('msg_information', sprintf("<b>%s</b> : %s", __('Warning'), __('in order to make use of virtual hosts or WebDAV, you need to set $globals->rooturl to a full URL starting with http:// or https:// in your Diogenes configuration file.')));
+  $page->assign('msg_information', __('Warning : in order to make use of virtual hosts or WebDAV, you need to set $globals->rooturl to a full URL starting with http:// or https:// in your Diogenes configuration file.'));
 }
 
 $page->assign('greeting',__("List of sites"));
