@@ -19,6 +19,7 @@
  */
  
 require_once 'diogenes.icons.inc.php';
+require_once 'Barrel/File.php';
 
 
 /** This class describes a Barrel Page.
@@ -162,15 +163,17 @@ class Diogenes_Barrel_Page
     global $globals;
     $props = $this->props;
     
-    $topbar = array (
-      array( __("pages catalog"), "pages"),
-    );
+    $topbar = array ();
     
     if ($props['PID']) {    
+      $hp = $this->barrel->getPID('');
+      array_push($topbar, array(__("home"), ($props['PID'] == $hp) ? "" : "files?dir=$hp"));
+      array_push($topbar, array(__("parent page"), $props['parent'] ? "files?dir=".$props['parent'] : ""));
+
+      array_push($topbar, array( __("browse files"), "files?dir={$props['PID']}" ));
       array_push($topbar, array( __("page properties"), "pages?dir={$props['PID']}" ));
       array_push($topbar, array( __("view page"), "../". $this->getLocation()));
-      array_push($topbar, array( __("browse files"), "files?dir={$props['PID']}" ));
-      
+      array_push($topbar, array(__("add a page"), "pages?action=edit&parent=".$props['PID']) );
       if ($this->barrel->flags->hasFlag("plug")) {
         array_push($topbar, array( __("plugins"), "plugins?plug_page={$props['PID']}" ) );
       }
@@ -181,6 +184,23 @@ class Diogenes_Barrel_Page
   }
   
   
+  /** Build the 'File' toolbar
+   */
+  function make_doc_toolbar(&$rcs)
+  {
+    global $globals;
+
+    if ($globals->word_import && file_exists($rcs->spoolPath($this->props['PID'],$globals->wordfile)) ) {
+      $bfile = new Diogenes_Barrel_File($this, $globals->wordfile);
+      $toolbar = $bfile->make_toolbar(0);
+    } else {
+      $bfile = new Diogenes_Barrel_File($this, $globals->htmlfile);
+      $toolbar = $bfile->make_toolbar(1);
+    }
+    return $toolbar;
+  }
+
+
   /** Write the page's properties to database
    *
    * @param $homepage
