@@ -1,7 +1,7 @@
 <?php
 require_once 'diogenes.common.inc.php';
 require_once 'diogenes.admin.inc.php';
-require_once 'diogenes.compose.inc.php';
+require_once 'diogenes.text.inc.php';
 require_once 'Barrel/Page.php';
 require_once 'Barrel/File.php';
 
@@ -42,7 +42,7 @@ case "update":
   break;
 }
 
-$rev = array_shift($rcs->logParse($dir,$file));
+$rev = array_shift($tmparr = $rcs->logParse($dir,$file));
 
 // protect PHP code and XHTML tags
 $rawdoc = file_get_contents($myfile);
