@@ -34,8 +34,6 @@ $canedit = $_SESSION['session']->hasPerms($fpage->props['wperms']);
 $page->assign('canedit', $canedit);
 
 // translations
-$page->assign('msg_files', __("Files in current directory"));
-$page->assign('msg_file_operations', __("File operations"));
 $page->assign('msg_import',__("Import file"));
 $page->assign('msg_btn_fileop',__("Submit"));
 $page->assign('msg_btn_send',__("Send"));
@@ -59,6 +57,10 @@ $page->assign('msg_access',__("access"));
 $page->assign('msg_read_perms',__("read access"));
 $page->assign('msg_write_perms',__("write access"));
 
+// build navigation toolbar
+$page->toolbar(__("Page"), $fpage->make_toolbar());
+
+
 switch ($action) {
 case "file_create":
   if (!$canedit) break;
@@ -117,7 +119,6 @@ case "diff":
   $ffile = new Diogenes_Barrel_File($fpage, $target);
   $page->assign('greeting', __("Revision differences"). " - ". $fpage->getLocation($target));
   $page->assign('diff',$rcs->dispDiff($fpage->props['PID'], $target, $_REQUEST["r1"],$_REQUEST["r2"]));
-  $page->toolbar(__("Page"), $fpage->make_toolbar());
   $page->toolbar(__("File"), $ffile->make_toolbar(true));
   $page->display('admin-revs.tpl');
   exit;
@@ -157,7 +158,6 @@ case "revs":
   }
   
   $page->assign('entries', $rentries);
-  $page->toolbar(__("Page"), $fpage->make_toolbar());
   $page->toolbar(__("File"), $ffile->make_toolbar(true));
   $page->display('admin-revs.tpl');
   exit;
@@ -189,7 +189,7 @@ case "fileop":
 }
 
 // directory listing
-$page->toolbar(__("Page"), $fpage->make_toolbar());
+$page->toolbar(__("Document"), $fpage->make_doc_toolbar($rcs));
 $pageloc = $bbarrel->getLocation($fpage->props['PID']);
 $page->assign('greeting', __("File manager"). " - " .(strlen($pageloc) ? $pageloc : __("home")));
 $page->assign('maxsize',$maxsize);
