@@ -3,6 +3,7 @@ require_once 'diogenes.common.inc.php';
 require_once 'diogenes.admin.inc.php';
 
 $page = new DiogenesAdmin;
+$bbarrel =& $page->barrel;
 $page->assign('greeting',__("Site options"));
 $page->assign('post',$page->script_self());
 
@@ -10,34 +11,37 @@ $page->assign('post',$page->script_self());
 $action = isset($_REQUEST['action']) ? $_REQUEST['action'] : "";
 switch ($action) {
 case "update":
-  $page->options->updateOption("title", $_REQUEST['title']);
-  $page->options->updateOption("description", $_REQUEST['description']);
-  $page->options->updateOption("keywords", $_REQUEST['keywords']);
-  $page->options->updateOption("favicon", $_REQUEST['favicon']);
+  $bbarrel->options->updateOption("title", $_REQUEST['title']);
+  $bbarrel->options->updateOption("description", $_REQUEST['description']);
+  $bbarrel->options->updateOption("keywords", $_REQUEST['keywords']);
+  $bbarrel->options->updateOption("favicon", $_REQUEST['favicon']);
   if (isset($_REQUEST['template']))
-    $page->options->updateOption("template", $_REQUEST['template']);
+    $bbarrel->options->updateOption("template", $_REQUEST['template']);
   if (isset($_REQUEST['template_dir']))
-    $page->options->updateOption("template_dir", $_REQUEST['template_dir']);
-  $page->options->updateOption("menu_min_level", $_REQUEST['menu_min_level']);
-  $page->options->updateOption("menu_style", $_REQUEST['menu_style']);
+    $bbarrel->options->updateOption("template_dir", $_REQUEST['template_dir']);
+  $bbarrel->options->updateOption("menu_min_level", $_REQUEST['menu_min_level']);
+  $bbarrel->options->updateOption("menu_style", $_REQUEST['menu_style']);
   if (isset($_REQUEST['menu_theme']))
-    $page->options->updateOption("menu_theme", $_REQUEST['menu_theme']);
-  $page->options->updateOption("menu_hide_diogenes", $_REQUEST['menu_hide_diogenes']);
+    $bbarrel->options->updateOption("menu_theme", $_REQUEST['menu_theme']);
+  $bbarrel->options->updateOption("menu_hide_diogenes", $_REQUEST['menu_hide_diogenes']);
+  
+  // log this action
+  $page->log('barrel_options', $bbarrel->alias.":*");
   break;
 }
 
 // fill out values
 /* general options */
-$page->assign('title', $page->options->title);
-$page->assign('description', $page->options->description);
-$page->assign('keywords', $page->options->keywords);
-$page->assign('favicon', $page->options->favicon);
+$page->assign('title', $bbarrel->options->title);
+$page->assign('description', $bbarrel->options->description);
+$page->assign('keywords', $bbarrel->options->keywords);
+$page->assign('favicon', $bbarrel->options->favicon);
 /* template options */
-$page->assign('template', $page->options->template);
+$page->assign('template', $bbarrel->options->template);
 $page->assign('templates', $page->getTemplates());
-if ($page->flags->hasFlag('tpl')) {
-  $page->assign('template_dir', $page->options->template_dir);
-  $res = $globals->db->query("SELECT PID,location from {$page->table_page} ORDER BY location");
+if ($bbarrel->hasFlag('tpl')) {
+  $page->assign('template_dir', $bbarrel->options->template_dir);
+  $res = $globals->db->query("SELECT PID,location from {$bbarrel->table_page} ORDER BY location");
   while (list($myPID,$myLocation) = mysql_fetch_row($res)) 
     $template_dirs[$myPID] = $myLocation ? $myLocation : "<home>";
   mysql_free_result($res);
@@ -45,15 +49,15 @@ if ($page->flags->hasFlag('tpl')) {
 }
 /* menu options */
 $page->assign('menu_hide_diogeness', array(0 => __("no"), 1 => __("yes")));
-$page->assign('menu_hide_diogenes', $page->options->menu_hide_diogenes);
+$page->assign('menu_hide_diogenes', $bbarrel->options->menu_hide_diogenes);
 $page->assign('menu_styles', $globals->menu_styles);
-$page->assign('menu_style', $page->options->menu_style);
-if ($page->options->menu_style == 1 || $page->options->menu_style == 2) {
+$page->assign('menu_style', $bbarrel->options->menu_style);
+if ($bbarrel->options->menu_style == 1 || $bbarrel->options->menu_style == 2) {
   $page->assign('menu_themes', $globals->menu_themes);
-  $page->assign('menu_theme', $page->options->menu_theme);
+  $page->assign('menu_theme', $bbarrel->options->menu_theme);
 }
 $page->assign('menu_levels',array(0=> __("fully expanded"), 1=>'1', 2=>'2', 3=>'3', 4=>'4'));
-$page->assign('menu_min_level', $page->options->menu_min_level);
+$page->assign('menu_min_level', $bbarrel->options->menu_min_level);
 
 // translations
 $page->assign('msg_general_options', __("general options"));
