@@ -60,16 +60,6 @@ class DiogenesCorePage extends Smarty {
   }
 
 
-  /** Check that $_SESSION['log'] is usable
-   *
-   * @see DiogenesRcs,DiogenesCvs
-   */
-  function checkLogger()
-  {
-    return isset($_SESSION['log']) && is_object($_SESSION['log']);
-  }
-
-
   /** Return the current script location.
    */
   function script_self() {
